====
pyn5
====


.. image:: https://img.shields.io/pypi/v/pyn5.svg
        :target: https://pypi.python.org/pypi/pyn5

.. image:: https://travis-ci.org/pattonw/rust-pyn5.svg?branch=master
        :target: https://travis-ci.org/pattonw/rust-pyn5

.. image:: https://readthedocs.org/projects/pyn5/badge/?version=latest
        :target: https://rust-pyn5.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python wrapper around rust-n5.


* Free software: MIT license
* Documentation: https://pyn5.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
